/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.naveditor.actions

import com.android.tools.idea.naveditor.model.isActivity
import com.android.tools.idea.naveditor.model.isDestination
import com.android.tools.idea.naveditor.model.isStartDestination
import com.android.tools.idea.naveditor.model.setAsStartDestination
import com.android.tools.idea.naveditor.surface.NavDesignSurface
import com.intellij.openapi.actionSystem.AnActionEvent
import com.intellij.openapi.command.WriteCommandAction
import icons.StudioIcons

class StartDestinationToolbarAction(surface: NavDesignSurface) :
  ToolbarAction(surface, "Assign start destination", StudioIcons.NavEditor.Toolbar.ASSIGN_START) {

  override fun isEnabled(): Boolean = surface.selectionModel.selection.let {
    if (it.size != 1) {
      return false
    }

    val component = it[0]
    return component.isDestination && component != surface.currentNavigation && !component.isActivity && !component.isStartDestination
  }

  override fun actionPerformed(e: AnActionEvent) {
    surface.selectionModel.selection.firstOrNull()?.let {
      WriteCommandAction.runWriteCommandAction(it.model.project) {
        it.setAsStartDestination()
      }
    }
  }
}